| ToolPRROC | R Documentation |
R6 class of the PRROC tool
An R6 class object.
ToolPRROC is a wrapper class for
the PRROC tool, which
is an R library that provides calculations of ROC and Precision-Recall
curves.
ToolIFBase -> ToolPRROC
ToolPRROC$new()Default class initialization method.
ToolPRROC$new(...)
...set value for curve, minStepSize,
aucType.
ToolPRROC$set_curve()A Boolean value to specify whether precision-recall curve is calculated.
ToolPRROC$set_curve(val)
valTRUE: calculate, FALSE: not calculate.
ToolPRROC$set_minStepSize()A numeric value to specify the minimum step size between two intermediate points.
ToolPRROC$set_minStepSize(val)
valStep size between two points.
ToolPRROC$set_aucType()Set the AUC calculation method
ToolPRROC$set_aucType(val)
val1: integral, 2: Davis Goadrich
ToolPRROC$clone()The objects of this class are cloneable with this method.
ToolPRROC$clone(deep = FALSE)
deepWhether to make a deep clone.
This class is derived from ToolIFBase.
create_toolset for creating a list of tools.
## Initialization
toolprroc <- ToolPRROC$new()
## Show object info
toolprroc
## create_toolset should be used for benchmarking and curve evaluation
toolprroc2 <- create_toolset("PRROC")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.