Toolprecrec: Toolprecrec

ToolprecrecR Documentation

Toolprecrec

Description

R6 class of the precrec tool

Format

An R6 class object.

Details

Toolprecrec is a wrapper class for the precrec tool, which is an R library that provides calculations of ROC and Precision-Recall curves.

Super class

ToolIFBase -> Toolprecrec

Methods

Public methods

Inherited methods

Toolprecrec$new()

Default class initialization method.

Usage
Toolprecrec$new(...)
Arguments
...

set value for x_bins.


Toolprecrec$set_x_bins()

Set the number of supporting points as the number of bins.

Usage
Toolprecrec$set_x_bins(x_bins)
Arguments
x_bins

set value for x_bins.


Toolprecrec$clone()

The objects of this class are cloneable with this method.

Usage
Toolprecrec$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

See Also

This class is derived from ToolIFBase. create_toolset for creating a list of tools.

Examples

## Initialization
toolprecrec <- Toolprecrec$new()

## Show object info
toolprecrec

## create_toolset should be used for benchmarking and curve evaluation
toolprecrec2 <- create_toolset("precrec")


prcbench documentation built on Sept. 26, 2026, 5:06 p.m.