Toolyardstick: Toolyardstick

ToolyardstickR Documentation

Toolyardstick

Description

R6 class of the yardstick tool

Format

An R6 class object.

Details

Toolyardstick is a wrapper class for the yardstick tool, which is an R library of the tidymodels ecosystem that provides calculations of various model performance measures.

Super class

ToolIFBase -> Toolyardstick

Methods

Public methods

Inherited methods

Toolyardstick$clone()

The objects of this class are cloneable with this method.

Usage
Toolyardstick$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

See Also

This class is derived from ToolIFBase. create_toolset for creating a list of tools.

Examples

## Initialization
toolyardstick <- Toolyardstick$new()

## Show object info
toolyardstick

## create_toolset should be used for benchmarking and curve evaluation
toolyardstick2 <- create_toolset("yardstick")


prcbench documentation built on Sept. 26, 2026, 5:06 p.m.