Learn R Programming

prcbench (version 0.3.2)

ToolAUCCalculator: R6 class of the AUCCalculator tool

Description

ToolAUCCalculator is a wrapper class for the http://mark.goadrich.com/programs/AUC/{AUCCalculator} tool, which is a Java library that provides calculations of ROC and Precision-Recall curves.

Usage

ToolAUCCalculator

Arguments

format

An R6 class object.

Inheritance

ToolIFBase

See Also

This class is derived from ToolIFBase. create_toolset for creating a list of tools.

Examples

Run this code
## Initialization
toolauccalc <- ToolAUCCalculator$new()

## Show object info
toolauccalc

## create_toolset should be used for benchmarking and curve evaluation
toolauccalc2 <- create_toolset("AUCCalculator")

Run the code above in your browser using DataLab