Base class of performance evaluation tools.
Details
ToolIFBase is an abstract class to provide a uniform interface for
performance evaluation tools.
Methods
Default class initialization method.
Arguments
...
set value for setname, calc_auc,
store_res, x, y.
It calls the tool to calculate precision-recall curves.
Usage
ToolIFBase$call(testset, calc_auc, store_res)
Arguments
testset
R6 object generated by the create_testset
function.
calc_auc
A Boolean value to specify whether the AUC score should
be calculated.
store_res
A Boolean value to specify whether the calculated curve
is retrieved and stored.
Get the name of the tool.
Usage
ToolIFBase$get_toolname()
Set the name of the tool.
Usage
ToolIFBase$set_toolname(toolname)
Arguments
toolname
Name of the tool.
Get the name of the tool set.
Set the name of the tool set.
Usage
ToolIFBase$set_setname(setname)
Arguments
setname
Name of the tool set.
Get a list with curve values and the AUC score.
Get calculated recall values.
Get calculated precision values.
Pretty print of the tool interface
The objects of this class are cloneable with this method.
Usage
ToolIFBase$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.