R6 class of the yardstick tool
An R6 class object.
Toolyardstick is a wrapper class for
the yardstick tool,
which is an R library of the tidymodels ecosystem that provides
calculations of various model performance measures.
This class is derived from ToolIFBase.
create_toolset for creating a list of tools.
ToolIFBase -> Toolyardstick
## Initialization
toolyardstick <- Toolyardstick$new()
## Show object info
toolyardstick
#>
#> === Tool interface ===
#>
#> Tool name: yardstick
#> Calculate AUC score: Yes
#> Store results: Yes
#> Prediction performed: No
#> Available methods: call(testset, calc_auc, store_res)
#> get_toolname()
#> set_toolname(toolname)
#> get_setname()
#> set_setname(setname)
#> get_result()
#> get_x()
#> get_y()
#> get_auc()
#> Help file: help("Toolyardstick")
## create_toolset should be used for benchmarking and curve evaluation
toolyardstick2 <- create_toolset("yardstick")