| Toolyardstick | R Documentation |
R6 class of the yardstick tool
An R6 class object.
Toolyardstick is a wrapper class for
the yardstick tool,
which is an R library of the tidymodels ecosystem that provides
calculations of various model performance measures.
ToolIFBase -> Toolyardstick
Toolyardstick$clone()The objects of this class are cloneable with this method.
Toolyardstick$clone(deep = FALSE)
deepWhether to make a deep clone.
This class is derived from ToolIFBase.
create_toolset for creating a list of tools.
## Initialization
toolyardstick <- Toolyardstick$new()
## Show object info
toolyardstick
## create_toolset should be used for benchmarking and curve evaluation
toolyardstick2 <- create_toolset("yardstick")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.